caellion-python-commons: caellion/pycommons/stringutil/formatters.py File Reference

caellion-python-commons

Classes | Namespaces
formatters.py File Reference

Go to the source code of this file.

## Classes
class | caellion.pycommons.stringutil.formatters.InvalidDurationException
| This exception is raised whenever provided duration is zero or negative. More...
class | caellion.pycommons.stringutil.formatters.NumberFormatting
| This class provides various number formats. More...

## Namespaces
| caellion.pycommons.stringutil.formatters
| This module provides various string formatters.